@@ -1,7 +1,7 @@
 <?php
 	/*
-	MGB 0.6.x - OpenSource PHP and MySql Guestbook
-	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/
+	MGB 0.7.x - OpenSource PHP and MySql Guestbook
+	Copyright (C) 2004 - 2013 Juergen Grueneisl - http://www.m-gb.org/
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -16,163 +16,127 @@
 	You should have received a copy of the GNU General Public License
 	along with this program; if not, write to the Free Software
 	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+
+	==================
+	deactivate.inc.php
+	==================
 	*/
 
-	// ======================== //
-	// deactivate.inc.php - 2.0 //
-	// ======================== //
-	//
-	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //
-
 	// make sure nobody has direct acces to this script
-	if (!defined('ADMINISTRATION'))
-		{
+	if (!defined('ADMINISTRATION')) {
 		include ("error.html");
 		die();
-		}
-	else
-		{
-		if(check_rights($_GET['action'], $_SESSION['ID']))
-			{
+	} else {
+		if(check_rights($_GET['action'], $_SESSION['ID'])) {
 			// load config, settings and language files
 			require ("../includes/config.inc.php");
 			require ("../includes/functions.inc.php");
 			require ("../includes/load_settings.inc.php");
 			require ("../language/".$settings['language_path']."/lang_admin.php");
+
 			// load templates
-			require ("load_template_admin.inc.php");
+			$content_deactivate = mgb_load_template("admin", "default", "deactivate", $settings['debug_mode']);
 
 			// set number of site to "1" if it is "0"
 			if(!isset($_GET['p'])) { $_GET['p'] = 1; }
 
-			// connect to database
-			$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(deactivate.inc.php) Error, line 49: ".mysql_error());
-			@mysql_select_db($db['dbname'], $link) or die ("(deactivate.inc.php) Error, line 50: ".mysql_error());
-
 			$_POST['dropbox'] = cleanstr($_POST['dropbox']);
 
-			if(isset($_POST['dropbox']) AND $_POST['dropbox'] == 1)
-				{
-				$sql = "UPDATE `".$db['prefix']."entries` SET `checked` = '0' WHERE checked=1";
-				@mysql_query($sql, $link) or die ("(deactivate.inc.php) Error, line 57: ".mysql_error());
-				}
+			if(isset($_POST['dropbox']) AND $_POST['dropbox'] == 1) {
+				mgb_sql_connect("UPDATE `".$db['prefix']."entries` SET `checked` = '0' WHERE checked=1", "Error while deactivating all entries at once.", 0);
+				mgb_erase_cache("../cache/");
+			}
 
-			if(isset($_GET['id']))
-				{
-				$sql = "UPDATE `".$db['prefix']."entries` SET `checked` = '0' WHERE ID=".$_GET['id']." LIMIT 1";
-				@mysql_query($sql, $link) or die ("(deactivate.inc.php) Error, line 63: ".mysql_error());
-				}
+			if(isset($_GET['id'])) {
+				mgb_sql_connect("UPDATE `".$db['prefix']."entries` SET `checked` = '0' WHERE ID=".secure_value($_GET['id'])." LIMIT 1", "Error while deactivating entry.", 0);
+				mgb_erase_cache("../cache/");
+			}
 
 			// get total number of entries
-			$results = @mysql_query("SELECT COUNT(ID) FROM ".$db['prefix']."entries WHERE CHECKED=1") or die ("(deactivate.inc.php) Error, line 67: ".mysql_error());
+			$results = mgb_sql_connect("SELECT COUNT(ID) FROM ".$db['prefix']."entries WHERE checked=1", "Error while counting deactivated entries.", 1);
 			$total = @mysql_result($results, 0);
 
 			// compute how many pages there are
 			$p = ($total / 20);
 
-			if ($p <= 1)
-				{
+			if ($p <= 1) {
 				$p = 0;
-				if ($total > 1)
-					{
+				if ($total > 1) {
 					$how_many_entries = "<span class=\"admin\">".$total."&nbsp;".$lang['entries']."</span>";
-					}
-				elseif ($total == 0)
-					{
+				} elseif ($total == 0) {
 					$how_many_entries = "<span class=\"admin\">".$lang['no_activated_entries']."</span>";
-					}
-				else
-					{
+				} else {
 					$how_many_entries = "<span class=\"admin\">".$total."&nbsp;".$lang['entry']."</span>";
-					}
 				}
-			else
-				{
+			} else {
 				$p = ceil($p);
 				$how_many_entries = "<span class=\"admin\">".$total."&nbsp;".$lang['entries_on_pages']."</span>";
-				}
+			}
 
 			$load_start = ($_GET['p'] * 20) - 20;
 			$load_end = 20;
 
 			$pages_total = ceil($p);
 
-			if ($_GET['p'] == 1)
-				{
+			if ($_GET['p'] == 1) {
 				$sf_forwards = "<a class=\"admin\" href=\"admin.php?action=deactivate&amp;p=".($_GET['p'] + 1).$sid."\" title=\"".$lang['page_forwards']."\">".$lang['page_forwards_symbol']."</a>";
 				$sf_pagenumber = $_GET['p'];
-				if ($pages_total >= 3 )
-					{
+				if ($pages_total >= 3 ) {
 					$sf_last = "<a class=\"admin\" href=\"admin.php?action=deactivate&amp;p=".$pages_total."\" title=\"".$lang['page_last']."\">".$lang['page_last_symbol']."</a>";
-					}
 				}
+			}
 
-			if ($_GET['p'] > 1)
-				{
-				if (($pages_total >= 3) AND ($_GET['p'] > 2))
-					{
+			if ($_GET['p'] > 1) {
+				if (($pages_total >= 3) AND ($_GET['p'] > 2)) {
 					$sf_first = "<a class=\"admin\" href=\"admin.php?action=deactivate&amp;p=1".$sid."\" title=\"".$lang['page_first']."\">".$lang['page_first_symbol']."</a>";
-					}
+				}
 				$sf_backwards = "<a class=\"admin\" href=\"admin.php?action=deactivate&amp;p=".($_GET['p'] - 1).$sid."\" title=\"".$lang['page_backwards']."\">".$lang['page_backwards_symbol']."</a>";
 				$sf_pagenumber = $_GET['p'];
 				$sf_forwards = "<a class=\"admin\" href=\"admin.php?action=deactivate&amp;p=".($_GET['p'] + 1).$sid."\" title=\"".$lang['page_forwards']."\">".$lang['page_forwards_symbol']."</a>";
-				if (($pages_total >= 3) AND ($_GET['p'] < ($pages_total - 1)))
-					{
-					 $sf_last = "&nbsp;<a class=\"admin\" href=\"admin.php?action=deactivate&amp;p=".$pages_total.$sid."\" title=\"".$lang['page_last']."\">".$lang['page_last_symbol']."</a>";
-					}
+				if (($pages_total >= 3) AND ($_GET['p'] < ($pages_total - 1))) {
+					$sf_last = "&nbsp;<a class=\"admin\" href=\"admin.php?action=deactivate&amp;p=".$pages_total.$sid."\" title=\"".$lang['page_last']."\">".$lang['page_last_symbol']."</a>";
 				}
+			}
 
-			if ($_GET['p'] == $pages_total)
-				{
-				if ($pages_total >= 3)
-					{
+			if ($_GET['p'] == $pages_total) {
+				if ($pages_total >= 3) {
 					$sf_first = "<a class=\"admin\" href=\"admin.php?action=deactivate&amp;p=1".$sid."\" title=\"".$lang['page_first']."\">".$lang['page_first_symbol']."</a>";
-					}
+				}
 				$sf_backwards = "<a class=\"admin\" href=\"admin.php?action=deactivate&amp;p=".($_GET['p'] - 1).$sid."\" title=\"".$lang['page_backwards']."\">".$lang['page_backwards_symbol']."</a>";
 				$sf_pagenumber = $_GET['p'];
 				$sf_forwards = "";
-				}
+			}
 
-			if ($pages_total <= 0)
-				{
+			if ($pages_total <= 0) {
 				$content_scrolling_function = "<br><br>";
-				}
+			}
 
 			// load guestbook entries
-			$sql="SELECT * FROM ".$db['prefix']."entries WHERE checked=1 ORDER BY ID DESC LIMIT ".$load_start.",".$load_end;
-			$result = @mysql_query($sql, $link) or die ("(deactivate.inc.php) Error, line 143: ".mysql_error());
+			$result = mgb_sql_connect("SELECT * FROM ".$db['prefix']."entries WHERE checked=1 ORDER BY ID DESC LIMIT ".$load_start.",".$load_end, "Error while loading entries.", 1);
 
 			$counter = 0;
 
-			for($i = 0; $i < mysql_num_rows($result); $i++)
-				{
+			for($i = 0; $i < mysql_num_rows($result); $i++) {
 				$entry[$i] = mysql_fetch_array($result);
 				$counter++;
-				}
+			}
 
-			if ($counter <= 1)
-				{
-				if ($_GET['p'] == 1)
-					{
+			if ($counter <= 1) {
+				if ($_GET['p'] == 1) {
 					$add_page_nr = NULL;
-					}
-				else
-					{
+				} else {
 					$add_page_nr = "&amp;p=".($_GET['p'] - 1);
-					}
 				}
-			else
-				{
+			} else {
 				$add_page_nr = "&amp;p=".$_GET['p'];
-				}
+			}
 
 			// fill entry template with content
 			require ("../includes/functions.inc.php");
 
 			if(!isset($entry)) { $entry = NULL; }
 
-			for($i = 0; $i < count($entry); $i++)
-				{
+			for($i = 0; $i < count($entry); $i++) {
 				$page_entry[$i] = $content_deactivate;
 
 				if($entry[$i]['ip'] == NULL) { $entry[$i]['ip'] = "-"; }
@@ -199,20 +163,15 @@
 				$page_entry[$i] = template("ENTRY_HP", $entry[$i]['hp'], $page_entry[$i]);
 				$page_entry[$i] = template("ENTRY_COMMENT", $entry[$i]['comment'], $page_entry[$i]);
 				$page_entry[$i] = template("LANG_QUOTE", $lang['quote'], $page_entry[$i]);
-				$page_entry[$i] = template("DEACTIVATE", "<a href=\"admin.php?action=deactivate&amp;id=".$entry[$i]['ID'].$add_page_nr.$sid."\"><img class=\"icon\" src=\"templates/default/images/deactivate.png\" title=\"".$lang['deactivate_entry']."\" alt=\"".$lang['deactivate_entry']."\"></a>", $page_entry[$i]);			
+				$page_entry[$i] = template("DEACTIVATE", "<a href=\"admin.php?action=deactivate&amp;id=".$entry[$i]['ID'].$add_page_nr.$sid."\"><img class=\"icon\" src=\"templates/default/images/deactivate.png\" title=\"".$lang['deactivate_entry']."\" alt=\"".$lang['deactivate_entry']."\"></a>", $page_entry[$i]);
 				$page_entry[$i] = template("TEMPLATE_PATH", "templates/".$settings['template_path'], $page_entry[$i]);
 
 				if(!isset($page_include)) { $page_include = NULL; }
 				$page_include .= $page_entry[$i];
-				}
 			}
-		else
-			{
-			$page_include = "<span class=\"admin\">".$lang['errormessage4']."</span>";
+		} else {
+			$page_include = "<span class=\"admin\">".$lang['errormessage'][4]."</span>";
 			$content_scrolling_function = "<br>";
-			}
 		}
-
-		// close sql connection
-		@mysql_close($link);
+	}
 ?>
